@@ -1,23 +1,19 @@
 #include <config.h>
 #include <errno.h>
+#include <locale.h>
 #include <stdarg.h>
 #include <string.h>
 #include <stdlib.h>
 #include <unistd.h>
 #include <glib.h>
 #include "gnome-defs.h"
-#include "gnome-util.h"
+#include "gnome-file.h"
 #include "libintl.h"
 
-char *gnome_user_home_dir = 0;
-char *gnome_user_dir = 0;
-
 void
 gnomelib_init (int *argc, char ***argv)
 {
-	gnome_user_home_dir = getenv ("HOME");
-	gnome_user_dir = g_concat_dir_and_file (gnome_user_home_dir, ".gnome");
-	mkdir (gnome_user_dir, 0755);
+        mkdir (gnome_file_from_home_dir(""), 0755);
 
 	setlocale (LC_ALL, "");
 	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
